@@ -12,23 +12,7 @@
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 
-"""Implements ``callable`` using ctypes (useful on Python 3.0 and 3.1)
-
-Most Python versions have a native builtin function called ``callable``
-which checks if the argument is a callable object.
-
-Python 3 initially removed the builtin function (but kept the internal
-C function), before adding it back in Python 3.2 because no alternative
-is truly equivalent in all cases.
-
-This module provides a function named ``callable`` which is equivalent
-to the native ``callable``, by directly accessing the underlying CPython
-API through the ``ctypes`` module.
-
-This isn't very useful by itself for most Python versions, but it is an
-essential building block for enabling code relying on ``callable`` to
-work on Python 3.0 and 3.1.
-"""
+"""Implements ``callable`` using ctypes (useful on CPython 3.0 and 3.1)."""
 
 
 from ctypes import py_object as _py_object
@@ -36,7 +20,7 @@ from ctypes import pythonapi as _pythonapi
 
 
 __all__ = ('callable',)
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 
 
 _PyCallable_Check = _pythonapi.PyCallable_Check  # pylint: disable=invalid-name
